#include <msp/datafile/collection.h>
#include <msp/gl/renderer.h>
#include <msp/gl/texture2d.h>
#include "demo.h"
#include "fadeoverlay.h"

using namespace std;

namespace Msp {
namespace DemoScene {

FadeOverlay::FadeOverlay(DataFile::Collection &resources):
	mesh(get_fullscreen_quad()),
	shprog(resources.get<GL::Program>("fade.glsl")),
	color(0.0f, 0.0f, 0.0f, 0.0f)
{
	shdata.uniform("color", color);
}

void FadeOverlay::set_color(const GL::Color &c)
{
	color = c;
	shdata.uniform("color", color);
}

void FadeOverlay::render(GL::Renderer &renderer, const GL::Texture2D &color_buf, const GL::Texture2D &)
{
	GL::Renderer::Push push(renderer);
	renderer.set_shader_program(&shprog, &shdata);
	renderer.set_texture(&color_buf);
	mesh.draw(renderer);
}


FadeOverlay::Fade::Fade():
	ColorFadeAction(GL::Color(0.0f, 0.0f, 0.0f, 0.0f)),
	overlay(0)
{ }

FadeOverlay::Fade::Fade(FadeOverlay &o, const GL::Color &c):
	ColorFadeAction(c),
	overlay(&o)
{ }

void FadeOverlay::Fade::validate() const
{
	if(!overlay)
		throw logic_error("null overlay");
}


FadeOverlay::Fade::Loader::Loader(Fade &f, Demo &d):
	DataFile::DerivedObjectLoader<Fade, Action::Loader>(f, d)
{
	add("overlay", &Loader::overlay);
	add("color", &Loader::color);
}

void FadeOverlay::Fade::Loader::overlay(const string &n)
{
	obj.overlay = &demo.get_thing<FadeOverlay>(n);
}

void FadeOverlay::Fade::Loader::color(float r, float g, float b, float a)
{
	obj.end_color = GL::Color(r, g, b, a);
}

} // namespace DemoScene
} // namespace Msp
