#include <msp/gl/blend.h>
#include <msp/gl/framebuffer.h>
#include <msp/gl/renderer.h>
#include <msp/strings/format.h>
#include "launchscreen.h"

namespace Msp {
namespace DemoScene {

LaunchScreen::LaunchScreen(Resources &resources):
	font(resources.get_ui_font()),
	tech(resources.get_ui_text_technique()),
	countdown(font, &tech),
	countdown_value(0),
	enter_prompt(font, &tech),
	esc_prompt(font, &tech)
{
	countdown.set_alignment(GL::Text::CENTER);

	enter_prompt.set_alignment(GL::Text::CENTER);
	enter_prompt.set_text("Press ENTER now to remain windowed");

	esc_prompt.set_alignment(GL::Text::CENTER);
	esc_prompt.set_text("Press ESC at any time to exit");

	camera.set_orthographic(1920, 1080);
	camera.set_depth_clip(-1, 1);
}

void LaunchScreen::set_countdown(unsigned c)
{
	if(c!=countdown_value)
	{
		countdown_value = c;
		countdown.set_text(format("Going fullscreen in %d...", countdown_value));
	}
}

void LaunchScreen::render()
{
	GL::Framebuffer::system().clear(GL::COLOR_BUFFER_BIT);
	GL::Bind blend(GL::Blend::alpha());
	GL::Renderer renderer(&camera);
	renderer.transform(GL::Matrix().scale(48).translate(0, 1.2, 0));
	countdown.render(renderer);
	renderer.transform(GL::Matrix::translation(0, -1.2, 0));
	enter_prompt.render(renderer);
	renderer.transform(GL::Matrix::translation(0, -1.2, 0));
	esc_prompt.render(renderer);
}

} // namespace DemoScene
} // namespace Msp
